Maintainer is [Jens Klein](https://github.com/jensens)

Several people helped to make this package work see [GitHub](https://github.com/collective/pas.plugins.authomatic/graphs/contributors) for the whole list.
